/**
 * `spriteful-db-image`
 * lazy fetches and loads an image from firebase cloud firestore
 *
 * @customElement
 * @polymer
 * @demo demo/index.html
 */
import {
  SpritefulElement, 
  htmlTemplate
}                 from '@spriteful/spriteful-element/spriteful-element.js';
import {
  isOnScreen, 
  schedule
}                 from '@spriteful/utils/utils.js';
import htmlString from './spriteful-db-image.html';
import services   from '@spriteful/services/services.js';
import '@polymer/iron-image/iron-image.js';


class SpritefulDbImage extends SpritefulElement {
  static get is() { return 'spriteful-db-image'; }

  static get template() {
    return htmlTemplate(htmlString);
  }


  static get properties() {
    return {

      coll: String,

      doc: String,

      alt: {
        type: String,
        value: ''
      },

      sizing: {
        type: String,
        value: 'cover' // or 'contain'
      },

      _lazyImage: String,
 
    }
  }


  static get observers() {
    return [
      '__missingAlt(alt)',
      '__collDocChanged(coll, doc)'
    ];
  }


  __missingAlt(alt) {
    if (!alt) {
      console.warn(this, 'missing alt tag');
    } 
  }


  async __collDocChanged(coll, doc) {
    if (!coll || !doc) { return; }
    await schedule(); // allow first layout/paint before measuring
    await isOnScreen(this);
    const {images}  = await services.get({coll: this.coll, doc: this.doc});
    const [key]     = Object.keys(images);
    this._lazyImage = images[key].url;   
  }

}

window.customElements.define(SpritefulDbImage.is, SpritefulDbImage);
